@@ -13,12 +13,12 @@
 ##############################################################################
 """List Formatter Implementation
 
-$Id: formatter.py 76933 2007-06-22 02:20:21Z srichter $
+$Id: formatter.py 81280 2007-10-31 16:50:06Z srichter $
 """
 __docformat__ = "reStructuredText"
 from xml.sax.saxutils import quoteattr
 from zope.app.pagetemplate import ViewPageTemplateFile
-from zope.app.session.interfaces import ISession
+from zope.session.interfaces import ISession
 from zc.table import table, column, interfaces
 
 
@@ -69,10 +69,11 @@ class ListFormatter(table.SortingFormatterMixin, table.AlternatingRowFormatter):
         name = column.name
         if self.prefix:
             name = self.prefix + name
+        isSortedOn = self.sortOn[0] == column.name
         isAscending = self.sortOn[0] == column.name and not self.sortOn[1]
         isDecending = self.sortOn[0] == column.name and self.sortOn[1]
         return self.sortedHeaderTemplate(
-            header=header, name=name,
+            header=header, name=name, isSortedOn=isSortedOn,
             isAscending=isAscending, isDecending=isDecending)
 
     def renderContents(self):
